@@ -13,22 +13,20 @@
  * permissions and limitations under the License.
  */
 
-#include "s2n_test.h"
-
 #include <stdint.h>
+
 #include "api/s2n.h"
-
-#include "tls/extensions/s2n_server_key_share.h"
-#include "tls/extensions/s2n_client_key_share.h"
-#include "tls/s2n_security_policies.h"
-
-#include "tls/s2n_tls13.h"
-#include "testlib/s2n_testlib.h"
-#include "testlib/s2n_nist_kats.h"
-#include "stuffer/s2n_stuffer.h"
-#include "utils/s2n_safety.h"
 #include "pq-crypto/s2n_pq.h"
+#include "s2n_test.h"
+#include "stuffer/s2n_stuffer.h"
+#include "testlib/s2n_nist_kats.h"
+#include "testlib/s2n_testlib.h"
+#include "tls/extensions/s2n_client_key_share.h"
+#include "tls/extensions/s2n_server_key_share.h"
+#include "tls/s2n_security_policies.h"
+#include "tls/s2n_tls13.h"
 #include "utils/s2n_bitmap.h"
+#include "utils/s2n_safety.h"
 
 #define HELLO_RETRY_MSG_NO 1
 
@@ -45,11 +43,11 @@ int main(int argc, char **argv)
     /* Test s2n_server_key_share_send_check_ecdhe */
     {
         struct s2n_security_policy test_security_policy_no_x25519 = {
-                .minimum_protocol_version = S2N_TLS10,
-                .cipher_preferences = &cipher_preferences_test_all_tls13,
-                .kem_preferences = &kem_preferences_null,
-                .signature_preferences = &s2n_signature_preferences_20200207,
-                .ecc_preferences = &s2n_ecc_preferences_20140601,
+            .minimum_protocol_version = S2N_TLS10,
+            .cipher_preferences = &cipher_preferences_test_all_tls13,
+            .kem_preferences = &kem_preferences_null,
+            .signature_preferences = &s2n_signature_preferences_20200207,
+            .ecc_preferences = &s2n_ecc_preferences_20140601,
         };
 
         struct s2n_connection *conn = NULL;
@@ -79,7 +77,7 @@ int main(int argc, char **argv)
         EXPECT_SUCCESS(s2n_server_key_share_send_check_ecdhe(conn));
 
         EXPECT_SUCCESS(s2n_connection_free(conn));
-    }
+    };
 
     /* Test s2n_extensions_server_key_share_send_size */
     {
@@ -108,7 +106,7 @@ int main(int argc, char **argv)
         EXPECT_EQUAL(6, s2n_extensions_server_key_share_send_size(conn));
 
         EXPECT_SUCCESS(s2n_connection_free(conn));
-    }
+    };
 
     /* Test s2n_server_key_share_extension.send sends key share success (ECDHE) */
     {
@@ -141,7 +139,7 @@ int main(int argc, char **argv)
         }
 
         EXPECT_SUCCESS(s2n_connection_free(conn));
-    }
+    };
 
     /* Test s2n_server_key_share_extension.send sends IANA ID for HRR (ECDHE) */
     {
@@ -173,7 +171,7 @@ int main(int argc, char **argv)
         }
 
         EXPECT_SUCCESS(s2n_connection_free(conn));
-    }
+    };
 
     /* Test s2n_server_key_share_extension.send for failures */
     {
@@ -192,7 +190,7 @@ int main(int argc, char **argv)
         EXPECT_FAILURE_WITH_ERRNO(s2n_server_key_share_extension.send(conn, &stuffer), S2N_ERR_ECDHE_UNSUPPORTED_CURVE);
 
         EXPECT_SUCCESS(s2n_connection_free(conn));
-    }
+    };
 
     /* Test s2n_server_key_share_extension.recv with supported curves */
     {
@@ -207,8 +205,8 @@ int main(int argc, char **argv)
 
             EXPECT_SUCCESS(s2n_connection_get_ecc_preferences(server_send_conn, &ecc_pref));
             EXPECT_NOT_NULL(ecc_pref);
-  
-            struct s2n_stuffer* extension_stuffer = &server_send_conn->handshake.io;
+
+            struct s2n_stuffer *extension_stuffer = &server_send_conn->handshake.io;
 
             server_send_conn->kex_params.server_ecc_evp_params.negotiated_curve = ecc_pref->ecc_curves[i];
             server_send_conn->kex_params.client_ecc_evp_params.negotiated_curve = ecc_pref->ecc_curves[i];
@@ -229,14 +227,13 @@ int main(int argc, char **argv)
             EXPECT_SUCCESS(s2n_connection_free(client_recv_conn));
 
             i += 1;
-        } while (i<ecc_pref->count);
-    }
+        } while (i < ecc_pref->count);
+    };
 
     /* Test s2n_server_key_share_extension.recv with various sample payloads */
     {
         /* valid extension payloads */
-        if (s2n_is_evp_apis_supported())
-        {
+        if (s2n_is_evp_apis_supported()) {
             /* Payload values were generated by connecting to openssl */
             const char *key_share_payloads[] = {
                 /* x25519 */
@@ -307,7 +304,7 @@ int main(int argc, char **argv)
 
                 EXPECT_SUCCESS(s2n_stuffer_free(&extension_stuffer));
                 EXPECT_SUCCESS(s2n_connection_free(client_conn));
-            }
+            };
         }
 
         /* Test error handling parsing broken/trancated p256 key share */
@@ -325,7 +322,7 @@ int main(int argc, char **argv)
 
             EXPECT_SUCCESS(s2n_stuffer_free(&extension_stuffer));
             EXPECT_SUCCESS(s2n_connection_free(client_conn));
-        }
+        };
 
         /* Test failure for receiving p256 key share for client configured p384 key share */
         {
@@ -352,8 +349,8 @@ int main(int argc, char **argv)
 
             EXPECT_SUCCESS(s2n_stuffer_free(&extension_stuffer));
             EXPECT_SUCCESS(s2n_connection_free(client_conn));
-        }
-    }
+        };
+    };
 
     /* Test Shared Key Generation */
     {
@@ -392,16 +389,16 @@ int main(int argc, char **argv)
         /* Server generates shared key based on Server's Key and Client's public key  */
         struct s2n_blob server_shared_secret = { 0 };
         EXPECT_SUCCESS(s2n_ecc_evp_compute_shared_secret_from_params(
-            &server_conn->kex_params.server_ecc_evp_params,
-            &server_conn->kex_params.client_ecc_evp_params,
-            &server_shared_secret));
+                &server_conn->kex_params.server_ecc_evp_params,
+                &server_conn->kex_params.client_ecc_evp_params,
+                &server_shared_secret));
 
         /* Clients generates shared key based on Client's Key and Server's public key */
         struct s2n_blob client_shared_secret = { 0 };
         EXPECT_SUCCESS(s2n_ecc_evp_compute_shared_secret_from_params(
-            &client_conn->kex_params.client_ecc_evp_params,
-            &client_conn->kex_params.server_ecc_evp_params,
-            &client_shared_secret));
+                &client_conn->kex_params.client_ecc_evp_params,
+                &client_conn->kex_params.server_ecc_evp_params,
+                &client_shared_secret));
 
         /* Test that server shared secret matches client shared secret */
         if (ecc_pref->ecc_curves[0] == &s2n_ecc_curve_secp256r1 || ecc_pref->ecc_curves[0] == &s2n_ecc_curve_secp384r1) {
@@ -421,7 +418,7 @@ int main(int argc, char **argv)
         EXPECT_SUCCESS(s2n_stuffer_free(&key_share_extension));
         EXPECT_SUCCESS(s2n_connection_free(client_conn));
         EXPECT_SUCCESS(s2n_connection_free(server_conn));
-    }
+    };
 
     /* Test s2n_server_key_share_extension.send with supported curve not in s2n_ecc_preferences list selected */
     if (s2n_is_evp_apis_supported()) {
@@ -506,66 +503,66 @@ int main(int argc, char **argv)
             EXPECT_SUCCESS(s2n_stuffer_free(key_share_extension));
             EXPECT_SUCCESS(s2n_connection_free(server_conn));
             EXPECT_SUCCESS(s2n_connection_free(client_conn));
-        }
+        };
         EXPECT_SUCCESS(s2n_disable_tls13_in_test());
-    }
+    };
 
     {
         /* KEM groups with Test Vectors defined in /tests/unit/kats/tls13_server_hybrid_key_share_recv.kat */
         const struct s2n_kem_group *test_kem_groups[] = {
-                &s2n_secp256r1_kyber_512_r3,
+            &s2n_secp256r1_kyber_512_r3,
 #if EVP_APIS_SUPPORTED
-                &s2n_x25519_kyber_512_r3,
+            &s2n_x25519_kyber_512_r3,
 #endif
         };
 
         const struct s2n_kem_preferences test_kem_prefs = {
-                .kem_count = 0,
-                .kems = NULL,
-                .tls13_kem_group_count = s2n_array_len(test_kem_groups),
-                .tls13_kem_groups = test_kem_groups,
+            .kem_count = 0,
+            .kems = NULL,
+            .tls13_kem_group_count = s2n_array_len(test_kem_groups),
+            .tls13_kem_groups = test_kem_groups,
         };
 
         const struct s2n_security_policy test_security_policy = {
-                .minimum_protocol_version = S2N_SSLv3,
-                .cipher_preferences = &cipher_preferences_test_all_tls13,
-                .kem_preferences = &test_kem_prefs,
-                .signature_preferences = &s2n_signature_preferences_20200207,
-                .ecc_preferences = &s2n_ecc_preferences_20200310,
+            .minimum_protocol_version = S2N_SSLv3,
+            .cipher_preferences = &cipher_preferences_test_all_tls13,
+            .kem_preferences = &test_kem_prefs,
+            .signature_preferences = &s2n_signature_preferences_20200207,
+            .ecc_preferences = &s2n_ecc_preferences_20200310,
         };
 
         const struct s2n_kem_preferences test_all_supported_kem_prefs = {
-                .kem_count = 0,
-                .kems = NULL,
-                .tls13_kem_group_count = S2N_SUPPORTED_KEM_GROUPS_COUNT,
-                .tls13_kem_groups = ALL_SUPPORTED_KEM_GROUPS,
+            .kem_count = 0,
+            .kems = NULL,
+            .tls13_kem_group_count = S2N_SUPPORTED_KEM_GROUPS_COUNT,
+            .tls13_kem_groups = ALL_SUPPORTED_KEM_GROUPS,
         };
 
         const struct s2n_security_policy test_all_supported_kems_security_policy = {
-                .minimum_protocol_version = S2N_SSLv3,
-                .cipher_preferences = &cipher_preferences_test_all_tls13,
-                .kem_preferences = &test_all_supported_kem_prefs,
-                .signature_preferences = &s2n_signature_preferences_20200207,
-                .ecc_preferences = &s2n_ecc_preferences_20200310,
+            .minimum_protocol_version = S2N_SSLv3,
+            .cipher_preferences = &cipher_preferences_test_all_tls13,
+            .kem_preferences = &test_all_supported_kem_prefs,
+            .signature_preferences = &s2n_signature_preferences_20200207,
+            .ecc_preferences = &s2n_ecc_preferences_20200310,
         };
 
         const struct s2n_kem_group *kem_groups_kyber[] = {
-                &s2n_secp256r1_kyber_512_r3,
+            &s2n_secp256r1_kyber_512_r3,
         };
 
         const struct s2n_kem_preferences kem_prefs_kyber = {
-                .kem_count = 0,
-                .kems = NULL,
-                .tls13_kem_group_count = s2n_array_len(kem_groups_kyber),
-                .tls13_kem_groups = kem_groups_kyber,
+            .kem_count = 0,
+            .kems = NULL,
+            .tls13_kem_group_count = s2n_array_len(kem_groups_kyber),
+            .tls13_kem_groups = kem_groups_kyber,
         };
 
         const struct s2n_security_policy security_policy_kyber = {
-                .minimum_protocol_version = S2N_SSLv3,
-                .cipher_preferences = &cipher_preferences_test_all_tls13,
-                .kem_preferences = &kem_prefs_kyber,
-                .signature_preferences = &s2n_signature_preferences_20200207,
-                .ecc_preferences = &s2n_ecc_preferences_20200310,
+            .minimum_protocol_version = S2N_SSLv3,
+            .cipher_preferences = &cipher_preferences_test_all_tls13,
+            .kem_preferences = &kem_prefs_kyber,
+            .signature_preferences = &s2n_signature_preferences_20200207,
+            .ecc_preferences = &s2n_ecc_preferences_20200310,
         };
 
         /* Tests for s2n_server_key_share_extension.recv with hybrid PQ key shares */
@@ -580,11 +577,11 @@ int main(int argc, char **argv)
                 client_conn->security_policy_override = &test_security_policy;
 
                 uint8_t iana_buffer[2];
-                struct s2n_blob iana_blob = {0};
-                struct s2n_stuffer iana_stuffer = {0};
+                struct s2n_blob iana_blob = { 0 };
+                struct s2n_stuffer iana_stuffer = { 0 };
                 EXPECT_SUCCESS(s2n_blob_init(&iana_blob, iana_buffer, 2));
                 EXPECT_SUCCESS(s2n_stuffer_init(&iana_stuffer, &iana_blob));
-                EXPECT_SUCCESS(s2n_stuffer_write_uint16(&iana_stuffer,test_security_policy.kem_preferences->tls13_kem_groups[0]->iana_id));
+                EXPECT_SUCCESS(s2n_stuffer_write_uint16(&iana_stuffer, test_security_policy.kem_preferences->tls13_kem_groups[0]->iana_id));
 
                 EXPECT_FAILURE_WITH_ERRNO(s2n_server_key_share_extension.recv(client_conn, &iana_stuffer), S2N_ERR_PQ_DISABLED);
 
@@ -603,8 +600,8 @@ int main(int argc, char **argv)
                         /* Read the test vectors from the KAT file (the PQ key shares are too long to hardcode inline).
                          * pq_private_key is intentionally missing DERFER_CLEANUP; it will get freed during s2n_connection_free. */
                         struct s2n_blob *pq_private_key = &client_conn->kex_params.client_kem_group_params.kem_params.private_key;
-                        DEFER_CLEANUP(struct s2n_stuffer pq_shared_secret = {0}, s2n_stuffer_free);
-                        DEFER_CLEANUP(struct s2n_stuffer key_share_payload = {0}, s2n_stuffer_free);
+                        DEFER_CLEANUP(struct s2n_stuffer pq_shared_secret = { 0 }, s2n_stuffer_free);
+                        DEFER_CLEANUP(struct s2n_stuffer key_share_payload = { 0 }, s2n_stuffer_free);
                         EXPECT_SUCCESS(s2n_read_server_key_share_hybrid_test_vectors(kem_group, pq_private_key,
                                 &pq_shared_secret, &key_share_payload));
 
@@ -629,13 +626,13 @@ int main(int argc, char **argv)
                         EXPECT_NOT_NULL(client_conn->kex_params.server_kem_group_params.kem_group);
                         EXPECT_EQUAL(client_conn->kex_params.server_kem_group_params.kem_group, kem_group);
                         EXPECT_NOT_NULL(client_conn->kex_params.server_kem_group_params.ecc_params.negotiated_curve);
-                        EXPECT_EQUAL(client_conn->kex_params.server_kem_group_params.ecc_params.negotiated_curve,kem_group->curve);
+                        EXPECT_EQUAL(client_conn->kex_params.server_kem_group_params.ecc_params.negotiated_curve, kem_group->curve);
                         EXPECT_NOT_NULL(client_conn->kex_params.server_kem_group_params.kem_params.kem);
                         EXPECT_EQUAL(client_conn->kex_params.server_kem_group_params.kem_params.kem, kem_group->kem);
 
                         EXPECT_EQUAL(client_conn->kex_params.client_kem_group_params.kem_group, kem_group);
-                        EXPECT_EQUAL(client_conn->kex_params.client_kem_group_params.ecc_params.negotiated_curve,kem_group->curve);
-                        EXPECT_EQUAL(client_conn->kex_params.client_kem_group_params.kem_params.kem,kem_group->kem);
+                        EXPECT_EQUAL(client_conn->kex_params.client_kem_group_params.ecc_params.negotiated_curve, kem_group->curve);
+                        EXPECT_EQUAL(client_conn->kex_params.client_kem_group_params.kem_params.kem, kem_group->kem);
                         EXPECT_NOT_NULL(client_conn->kex_params.client_kem_group_params.kem_params.shared_secret.data);
                         EXPECT_EQUAL(client_conn->kex_params.client_kem_group_params.kem_params.shared_secret.size,
                                 kem_group->kem->shared_secret_key_length);
@@ -646,7 +643,7 @@ int main(int argc, char **argv)
 
                         EXPECT_SUCCESS(s2n_connection_free(client_conn));
                     }
-                }
+                };
 
                 /* Test s2n_server_key_share_extension.recv with HRR for PQ */
                 {
@@ -660,7 +657,7 @@ int main(int argc, char **argv)
 
                     /* In the HRR, the server indicated p256+Kyber as it's choice in the key share extension */
                     const struct s2n_kem_group *kem_group = &s2n_secp256r1_kyber_512_r3;
-                    DEFER_CLEANUP(struct s2n_stuffer key_share_payload = {0}, s2n_stuffer_free);
+                    DEFER_CLEANUP(struct s2n_stuffer key_share_payload = { 0 }, s2n_stuffer_free);
                     EXPECT_SUCCESS(s2n_stuffer_alloc_ro_from_hex_string(&key_share_payload, "2F3A"));
 
                     /* Client should successfully parse the indicated group */
@@ -669,7 +666,7 @@ int main(int argc, char **argv)
                     EXPECT_NOT_NULL(client_conn->kex_params.server_kem_group_params.kem_group);
                     EXPECT_EQUAL(client_conn->kex_params.server_kem_group_params.kem_group, kem_group);
                     EXPECT_NOT_NULL(client_conn->kex_params.server_kem_group_params.ecc_params.negotiated_curve);
-                    EXPECT_EQUAL(client_conn->kex_params.server_kem_group_params.ecc_params.negotiated_curve,kem_group->curve);
+                    EXPECT_EQUAL(client_conn->kex_params.server_kem_group_params.ecc_params.negotiated_curve, kem_group->curve);
                     EXPECT_NOT_NULL(client_conn->kex_params.server_kem_group_params.kem_params.kem);
                     EXPECT_EQUAL(client_conn->kex_params.server_kem_group_params.kem_params.kem, kem_group->kem);
 
@@ -687,7 +684,7 @@ int main(int argc, char **argv)
                     EXPECT_NULL(client_conn->kex_params.server_kem_group_params.kem_params.shared_secret.data);
 
                     EXPECT_SUCCESS(s2n_connection_free(client_conn));
-                }
+                };
 
                 /* Various failure cases */
                 {
@@ -699,14 +696,14 @@ int main(int argc, char **argv)
 
                         /* Server sends a named group identifier that isn't in the client's KEM preferences */
                         const char *bad_group = "2F2C"; /* IANA ID for secp256r1_threebears-babybear-r2 (not imported into s2n) */
-                        DEFER_CLEANUP(struct s2n_stuffer bad_group_stuffer = {0}, s2n_stuffer_free);
+                        DEFER_CLEANUP(struct s2n_stuffer bad_group_stuffer = { 0 }, s2n_stuffer_free);
                         EXPECT_SUCCESS(s2n_stuffer_alloc_ro_from_hex_string(&bad_group_stuffer, bad_group));
                         EXPECT_FAILURE_WITH_ERRNO(s2n_server_key_share_extension.recv(client_conn, &bad_group_stuffer),
                                 S2N_ERR_ECDHE_UNSUPPORTED_CURVE);
 
                         /* Server sends a key share that is in the client's KEM preferences, but client didn't send a key share */
                         const char *wrong_share = "2F1F"; /* Full extension truncated - not necessary */
-                        DEFER_CLEANUP(struct s2n_stuffer wrong_share_stuffer = {0}, s2n_stuffer_free);
+                        DEFER_CLEANUP(struct s2n_stuffer wrong_share_stuffer = { 0 }, s2n_stuffer_free);
                         EXPECT_SUCCESS(s2n_stuffer_alloc_ro_from_hex_string(&wrong_share_stuffer, wrong_share));
                         EXPECT_FAILURE_WITH_ERRNO(s2n_server_key_share_extension.recv(client_conn, &wrong_share_stuffer),
                                 S2N_ERR_ECDHE_UNSUPPORTED_CURVE);
@@ -715,8 +712,8 @@ int main(int argc, char **argv)
                          * manipulate it as necessary. (We do this now, instead of earlier, because we needed
                          * client_kem_group_params[i].kem_params.private_key to be empty to test the previous case.) */
                         struct s2n_blob *pq_private_key = &client_conn->kex_params.client_kem_group_params.kem_params.private_key;
-                        DEFER_CLEANUP(struct s2n_stuffer pq_shared_secret = {0}, s2n_stuffer_free);
-                        DEFER_CLEANUP(struct s2n_stuffer key_share_payload = {0}, s2n_stuffer_free);
+                        DEFER_CLEANUP(struct s2n_stuffer pq_shared_secret = { 0 }, s2n_stuffer_free);
+                        DEFER_CLEANUP(struct s2n_stuffer key_share_payload = { 0 }, s2n_stuffer_free);
                         EXPECT_SUCCESS(s2n_read_server_key_share_hybrid_test_vectors(kem_group, pq_private_key,
                                 &pq_shared_secret, &key_share_payload));
 
@@ -736,9 +733,9 @@ int main(int argc, char **argv)
                         /* Server sends the correct (total) size, but the extension doesn't contain all the data */
                         uint8_t truncated_extension[10];
                         EXPECT_MEMCPY_SUCCESS(truncated_extension, key_share_payload.blob.data, 10);
-                        struct s2n_blob trunc_ext_blob = {0};
+                        struct s2n_blob trunc_ext_blob = { 0 };
                         EXPECT_SUCCESS(s2n_blob_init(&trunc_ext_blob, truncated_extension, 10));
-                        struct s2n_stuffer trunc_ext_stuffer = {0};
+                        struct s2n_stuffer trunc_ext_stuffer = { 0 };
                         EXPECT_SUCCESS(s2n_stuffer_init(&trunc_ext_stuffer, &trunc_ext_blob));
                         EXPECT_FAILURE_WITH_ERRNO(s2n_server_key_share_extension.recv(client_conn, &trunc_ext_stuffer),
                                 S2N_ERR_BAD_KEY_SHARE);
@@ -779,10 +776,10 @@ int main(int argc, char **argv)
 
                         EXPECT_SUCCESS(s2n_connection_free(client_conn));
                     }
-                }
+                };
             }
             EXPECT_SUCCESS(s2n_disable_tls13_in_test());
-        }
+        };
 
         /* Test s2n_server_key_share_send_check_pq_hybrid */
         {
@@ -830,7 +827,7 @@ int main(int argc, char **argv)
             }
 
             EXPECT_SUCCESS(s2n_connection_free(conn));
-        }
+        };
 
         /* Test s2n_server_key_share_extension.send sends key share success (PQ) */
         if (s2n_pq_is_enabled()) {
@@ -933,7 +930,7 @@ int main(int argc, char **argv)
             }
 
             EXPECT_SUCCESS(s2n_connection_free(conn));
-        }
+        };
 
         /* Test s2n_server_key_share_extension.send fails when both server_kem_group and server_curve are non-NULL */
         {
@@ -958,15 +955,16 @@ int main(int argc, char **argv)
             EXPECT_FAILURE_WITH_ERRNO(s2n_server_key_share_extension.send(conn, &stuffer), S2N_ERR_ECDHE_UNSUPPORTED_CURVE);
 
             EXPECT_SUCCESS(s2n_connection_free(conn));
-        }
-    }
+        };
+    };
 
     END_TEST();
     return 0;
 }
 
 static int s2n_read_server_key_share_hybrid_test_vectors(const struct s2n_kem_group *kem_group, struct s2n_blob *pq_private_key,
-        struct s2n_stuffer *pq_shared_secret, struct s2n_stuffer *key_share_payload) {
+        struct s2n_stuffer *pq_shared_secret, struct s2n_stuffer *key_share_payload)
+{
     FILE *kat_file = fopen("kats/tls13_server_hybrid_key_share_recv.kat", "r");
     POSIX_ENSURE_REF(kat_file);
 
@@ -985,7 +983,7 @@ static int s2n_read_server_key_share_hybrid_test_vectors(const struct s2n_kem_gr
     POSIX_GUARD(ReadHex(kat_file, pq_shared_secret_ptr, kem_group->kem->shared_secret_key_length, "pq_shared_secret = "));
 
     size_t key_share_payload_size =
-              S2N_SIZE_OF_NAMED_GROUP
+            S2N_SIZE_OF_NAMED_GROUP
             + S2N_SIZE_OF_KEY_SHARE_SIZE /* Not a typo; PQ shares have an overall (combined) size */
             + S2N_SIZE_OF_KEY_SHARE_SIZE /* and a size for each contribution of the hybrid share. */
             + kem_group->curve->share_size
