@@ -14,24 +14,22 @@
  */
 
 #include "s2n_test.h"
-
 #include "testlib/s2n_testlib.h"
-
 #include "tls/s2n_tls.h"
 /* To test static functions */
 #include "tls/s2n_server_new_session_ticket.c"
 
-#define TEST_TICKET_AGE_ADD  0x01, 0x02, 0x03, 0x04
-#define TEST_LIFETIME        0x00, 0x01, 0x01, 0x01
-#define TEST_TICKET          0x01, 0xFF, 0x23
+#define TEST_TICKET_AGE_ADD 0x01, 0x02, 0x03, 0x04
+#define TEST_LIFETIME       0x00, 0x01, 0x01, 0x01
+#define TEST_TICKET         0x01, 0xFF, 0x23
 
-#define ONE_HOUR_IN_NANOS   3600000000000
+#define ONE_HOUR_IN_NANOS 3600000000000
 
-#define TICKET_AGE_ADD_MARKER sizeof(uint8_t)  + /* message id  */ \
-                              SIZEOF_UINT24    + /* message len */ \
-                              sizeof(uint32_t)   /* ticket lifetime */
-#define RECORD_LEN_MARKER     sizeof(uint8_t) +  /* message type */ \
-                              sizeof(uint16_t)   /* protocol version */
+#define TICKET_AGE_ADD_MARKER sizeof(uint8_t) + /* message id  */ \
+        SIZEOF_UINT24 +                         /* message len */ \
+        sizeof(uint32_t)                        /* ticket lifetime */
+#define RECORD_LEN_MARKER sizeof(uint8_t) +     /* message type */ \
+        sizeof(uint16_t)                        /* protocol version */
 
 #define MAX_TEST_SESSION_SIZE 300
 
@@ -70,16 +68,16 @@ static int s2n_setup_test_ticket_key(struct s2n_config *config)
      *#        90b6c73bb50f9c3122ec844ad7c2b3e5 (32 octets)
      **/
     S2N_BLOB_FROM_HEX(ticket_key,
-    "077709362c2e32df0ddc3f0dc47bba63"
-    "90b6c73bb50f9c3122ec844ad7c2b3e5");
+            "077709362c2e32df0ddc3f0dc47bba63"
+            "90b6c73bb50f9c3122ec844ad7c2b3e5");
 
     /* Set up encryption key */
     uint64_t current_time;
     uint8_t ticket_key_name[16] = "2016.07.26.15\0";
     EXPECT_SUCCESS(s2n_config_set_session_tickets_onoff(config, 1));
     EXPECT_SUCCESS(config->wall_clock(config->sys_clock_ctx, &current_time));
-    EXPECT_SUCCESS(s2n_config_add_ticket_crypto_key(config, ticket_key_name, strlen((char *)ticket_key_name),
-                    ticket_key.data, ticket_key.size, current_time/ONE_SEC_IN_NANOS));
+    EXPECT_SUCCESS(s2n_config_add_ticket_crypto_key(config, ticket_key_name, strlen((char *) ticket_key_name),
+            ticket_key.data, ticket_key.size, current_time / ONE_SEC_IN_NANOS));
 
     return S2N_SUCCESS;
 }
@@ -93,8 +91,8 @@ static int s2n_setup_test_resumption_secret(struct s2n_connection *conn)
      *# da f8 6c c8 56 23 1f 2d 5a ba 46 c4 34 ec 19 6c
      **/
     S2N_BLOB_FROM_HEX(test_resumption_secret,
-    "7d f2 35 f2 03 1d 2a 05 12 87 d0 2b 02 41 b0 bf \
-         da f8 6c c8 56 23 1f 2d 5a ba 46 c4 34 ec 19 6c");
+            "7d f2 35 f2 03 1d 2a 05 12 87 d0 2b 02 41 b0 bf \
+             da f8 6c c8 56 23 1f 2d 5a ba 46 c4 34 ec 19 6c");
 
     /* Set up resumption secret */
     struct s2n_blob secret = { 0 };
@@ -130,7 +128,7 @@ int main(int argc, char **argv)
             /* Set up output stuffer */
             struct s2n_stuffer output = { 0 };
             EXPECT_SUCCESS(s2n_stuffer_growable_alloc(&output, 0));
-            
+
             EXPECT_OK(s2n_tls13_server_nst_write(conn, &output));
 
             uint8_t message_type = 0;
@@ -182,7 +180,7 @@ int main(int argc, char **argv)
             EXPECT_SUCCESS(s2n_connection_free(conn));
             EXPECT_SUCCESS(s2n_stuffer_free(&output));
             EXPECT_SUCCESS(s2n_config_free(config));
-        }
+        };
 
         /* tickets_sent overflow */
         {
@@ -190,7 +188,7 @@ int main(int argc, char **argv)
             struct s2n_connection *conn;
             EXPECT_NOT_NULL(conn = s2n_connection_new(S2N_SERVER));
             EXPECT_NOT_NULL(config = s2n_config_new());
-            
+
             EXPECT_SUCCESS(s2n_setup_test_ticket_key(config));
             EXPECT_SUCCESS(s2n_connection_set_config(conn, config));
 
@@ -207,7 +205,7 @@ int main(int argc, char **argv)
             EXPECT_SUCCESS(s2n_connection_free(conn));
             EXPECT_SUCCESS(s2n_stuffer_free(&output));
             EXPECT_SUCCESS(s2n_config_free(config));
-        }
+        };
 
         /** ticket_age_add values do not repeat after sending multiple new session tickets
          *= https://tools.ietf.org/rfc/rfc8446#section-4.6.1
@@ -258,8 +256,8 @@ int main(int argc, char **argv)
 
             /* Calculate extension list offset. Extension list should be last. */
             const uint32_t extension_list_offset = sizeof(uint32_t) /* max_early_data_size */
-                    + sizeof(uint16_t) /* size of extension */
-                    + sizeof(uint16_t) /* type of extension */;
+                    + sizeof(uint16_t)                              /* size of extension */
+                    + sizeof(uint16_t);                             /* type of extension */
 
             struct s2n_config *config = s2n_config_new();
             EXPECT_NOT_NULL(config);
@@ -294,7 +292,7 @@ int main(int argc, char **argv)
             EXPECT_SUCCESS(s2n_connection_free(conn));
             EXPECT_SUCCESS(s2n_stuffer_free(&output));
             EXPECT_SUCCESS(s2n_config_free(config));
-        }
+        };
 
         /* Can't write ticket larger than allowed size of a PSK identity */
         {
@@ -323,8 +321,8 @@ int main(int argc, char **argv)
 
             EXPECT_SUCCESS(s2n_connection_free(server_conn));
             EXPECT_SUCCESS(s2n_config_free(config));
-        }
-    }
+        };
+    };
 
     /* s2n_generate_ticket_lifetime */
     {
@@ -368,7 +366,7 @@ int main(int argc, char **argv)
         EXPECT_EQUAL(min_lifetime, ONE_WEEK_IN_SEC);
 
         EXPECT_SUCCESS(s2n_connection_free(conn));
-    }
+    };
 
     /* s2n_generate_ticket_nonce */
     {
@@ -376,11 +374,11 @@ int main(int argc, char **argv)
             uint16_t value;
             uint8_t expected_output[2];
         } test_cases[] = {
-            { .value = 0, .expected_output = { 0 , 0 } },
-            { .value = 1, .expected_output = { 0 , 1 } },
-            { .value = 20, .expected_output = { 0 , 20 } },
-            { .value = UINT8_MAX, .expected_output = { 0 , UINT8_MAX } },
-            { .value = UINT8_MAX + 1, .expected_output = { 1 , 0 } },
+            { .value = 0, .expected_output = { 0, 0 } },
+            { .value = 1, .expected_output = { 0, 1 } },
+            { .value = 20, .expected_output = { 0, 20 } },
+            { .value = UINT8_MAX, .expected_output = { 0, UINT8_MAX } },
+            { .value = UINT8_MAX + 1, .expected_output = { 1, 0 } },
             { .value = UINT16_MAX, .expected_output = { UINT8_MAX, UINT8_MAX } },
             { .value = UINT16_MAX - 1, .expected_output = { UINT8_MAX, UINT8_MAX - 1 } },
         };
@@ -395,7 +393,7 @@ int main(int argc, char **argv)
             EXPECT_EQUAL(test_cases[i].expected_output[0], data[0]);
             EXPECT_EQUAL(test_cases[i].expected_output[1], data[1]);
         }
-    }
+    };
 
     /* s2n_generate_ticket_age_add */
     {
@@ -410,7 +408,7 @@ int main(int argc, char **argv)
             { .value = { 0, 1, 0, 0 }, .expected_output = UINT16_MAX + 1 },
             { .value = { 0, 0, UINT8_MAX, UINT8_MAX }, .expected_output = UINT16_MAX },
             { .value = { UINT8_MAX, UINT8_MAX, UINT8_MAX, UINT8_MAX }, .expected_output = UINT32_MAX },
-            { .value = { UINT8_MAX, UINT8_MAX, UINT8_MAX, UINT8_MAX - 1}, .expected_output = UINT32_MAX - 1 },
+            { .value = { UINT8_MAX, UINT8_MAX, UINT8_MAX, UINT8_MAX - 1 }, .expected_output = UINT32_MAX - 1 },
         };
 
         for (size_t i = 0; i < s2n_array_len(test_cases); i++) {
@@ -421,7 +419,7 @@ int main(int argc, char **argv)
 
             EXPECT_EQUAL(output, test_cases[i].expected_output);
         }
-    }
+    };
 
     /* s2n_generate_session_secret */
     {
@@ -430,9 +428,11 @@ int main(int argc, char **argv)
          *# expanded (32 octets):  4e cd 0e b6 ec 3b 4d 87 f5 d6 02 8f 92 2c
          *# a4 c5 85 1a 27 7f d4 13 11 c9 e6 2d 2c 94 92 e1 c4 f3
          **/
+        /* clang-format off */
         S2N_BLOB_FROM_HEX(expected_session_secret,
-        "4e cd 0e b6 ec 3b 4d 87 f5 d6 02 8f 92 2c \
+                       "4e cd 0e b6 ec 3b 4d 87 f5 d6 02 8f 92 2c \
             a4 c5 85 1a 27 7f d4 13 11 c9 e6 2d 2c 94 92 e1 c4 f3");
+        /* clang-format on */
 
         struct s2n_connection *conn = s2n_connection_new(S2N_CLIENT);
         EXPECT_NOT_NULL(conn);
@@ -450,7 +450,7 @@ int main(int argc, char **argv)
         EXPECT_BYTEARRAY_EQUAL(output->data, expected_session_secret.data, expected_session_secret.size);
 
         EXPECT_SUCCESS(s2n_connection_free(conn));
-    }
+    };
 
     /* s2n_tls13_server_nst_recv */
     {
@@ -489,7 +489,7 @@ int main(int argc, char **argv)
 
             EXPECT_SUCCESS(s2n_connection_free(conn));
             EXPECT_SUCCESS(s2n_config_free(config));
-        }
+        };
 
         /* Not allowed in TLS1.2 */
         {
@@ -511,7 +511,7 @@ int main(int argc, char **argv)
             EXPECT_TRUE(s2n_stuffer_data_available(&input) > 0);
 
             EXPECT_SUCCESS(s2n_connection_free(conn));
-        }
+        };
 
         /* Tests session_ticket_cb correctly serializes session data from an arbitrary new session ticket message */
         {
@@ -558,34 +558,33 @@ int main(int argc, char **argv)
                 uint8_t *ticket = s2n_stuffer_raw_read(&session_stuffer, ticket_size);
                 EXPECT_NOT_NULL(ticket);
                 EXPECT_BYTEARRAY_EQUAL(ticket, test_ticket, ticket_size);
-            }
+            };
 
-            /* Check the serialized ticket_age_add is what was in the arbitrary nst message*/ 
+            /* Check the serialized ticket_age_add is what was in the arbitrary nst message */
             {
                 uint8_t test_ticket_age_add[] = { TEST_TICKET_AGE_ADD };
-                uint8_t ticket_age_add_marker = sizeof(uint8_t) + /* client state format */ \
-                                                sizeof(uint8_t) + /* protocol version */ \
-                                                sizeof(uint16_t) + /* cipher suite */ \
-                                                sizeof(uint64_t);  /* time */
+                uint8_t ticket_age_add_marker = sizeof(uint8_t) + /* client state format */
+                        sizeof(uint8_t) +                         /* protocol version */
+                        sizeof(uint16_t) +                        /* cipher suite */
+                        sizeof(uint64_t);                         /* time */
                 /* Skip to ticket_age_add */
                 EXPECT_SUCCESS((s2n_stuffer_skip_read(&session_stuffer, ticket_age_add_marker)));
 
                 uint8_t ticket_age_add[sizeof(uint32_t)] = { 0 };
                 EXPECT_SUCCESS(s2n_stuffer_read_bytes(&session_stuffer, ticket_age_add, sizeof(uint32_t)));
                 EXPECT_BYTEARRAY_EQUAL(ticket_age_add, test_ticket_age_add, sizeof(uint32_t));
-            }
+            };
 
             /* Check ticket lifetime is what was in the arbitrary nst message */
             {
                 uint8_t test_lifetime[] = { TEST_LIFETIME };
-                uint32_t expected_lifetime = test_lifetime[3] | (test_lifetime[2] << 8) | \
-                                            (test_lifetime[1] << 16) | (test_lifetime[0] << 24);
+                uint32_t expected_lifetime = test_lifetime[3] | (test_lifetime[2] << 8) | (test_lifetime[1] << 16) | (test_lifetime[0] << 24);
                 EXPECT_EQUAL(expected_lifetime, cb_session_lifetime);
-            }
+            };
             EXPECT_SUCCESS(s2n_connection_free(conn));
             EXPECT_SUCCESS(s2n_stuffer_free(&input));
             EXPECT_SUCCESS(s2n_config_free(config));
-        }
+        };
 
         /* Known values test */
         {
@@ -605,8 +604,9 @@ int main(int argc, char **argv)
              *#    5e 5b fb c3 88 e9 33 43 69 40 93 93 4a e4 d3 57 00 08 00 2a 00
              *#    04 00 00 04 00
              **/
-            S2N_BLOB_FROM_HEX(nst_message, 
-            "04 00 00 c9 00 00 00 1e fa d6 aa \
+            /* clang-format off */
+            S2N_BLOB_FROM_HEX(nst_message,
+                                             "04 00 00 c9 00 00 00 1e fa d6 aa \
                 c5 02 00 00 00 b2 2c 03 5d 82 93 59 ee 5f f7 af 4e c9 00 00 00 \
                 00 26 2a 64 94 dc 48 6d 2c 8a 34 cb 33 fa 90 bf 1b 00 70 ad 3c \
                 49 88 83 c9 36 7c 09 a2 be 78 5a bc 55 cd 22 60 97 a3 a9 82 11 \
@@ -617,7 +617,8 @@ int main(int argc, char **argv)
                 17 64 6f ac 5c 03 27 2e 97 07 27 c6 21 a7 91 41 ef 5f 7d e6 50 \
                 5e 5b fb c3 88 e9 33 43 69 40 93 93 4a e4 d3 57 00 08 00 2a 00 \
                 04 00 00 04 00");
-            
+            /* clang-format on */
+
             struct s2n_config *config = s2n_config_new();
             struct s2n_connection *conn = s2n_connection_new(S2N_CLIENT);
             EXPECT_NOT_NULL(conn);
@@ -641,7 +642,7 @@ int main(int argc, char **argv)
             EXPECT_SUCCESS(s2n_connection_free(conn));
             EXPECT_SUCCESS(s2n_stuffer_free(&input));
             EXPECT_SUCCESS(s2n_config_free(config));
-        }
+        };
 
         /* Self-talk test */
         {
@@ -676,7 +677,7 @@ int main(int argc, char **argv)
             EXPECT_SUCCESS(s2n_connection_free(server_conn));
             EXPECT_SUCCESS(s2n_stuffer_free(&stuffer));
             EXPECT_SUCCESS(s2n_config_free(config));
-        }
+        };
 
         /* Test that the client processes extensions.
          * Specifically, check for the early_data_indication extension. */
@@ -715,7 +716,7 @@ int main(int argc, char **argv)
             EXPECT_SUCCESS(s2n_connection_free(server_conn));
             EXPECT_SUCCESS(s2n_stuffer_free(&stuffer));
             EXPECT_SUCCESS(s2n_config_free(config));
-        }
+        };
 
         /* Test that the client can handle different max_early_data_size values. */
         {
@@ -755,7 +756,7 @@ int main(int argc, char **argv)
             EXPECT_SUCCESS(s2n_connection_free(server_conn));
             EXPECT_SUCCESS(s2n_stuffer_free(&stuffer));
             EXPECT_SUCCESS(s2n_config_free(config));
-        }
+        };
 
         /* Test that the client rejects tickets with invalid ticket_lifetime */
         {
@@ -792,7 +793,7 @@ int main(int argc, char **argv)
                 EXPECT_EQUAL(s2n_connection_get_session_length(conn), 0);
 
                 EXPECT_SUCCESS(s2n_connection_free(conn));
-            }
+            };
 
             /**
              *= https://tools.ietf.org/rfc/rfc8446#section-4.6.1
@@ -818,11 +819,11 @@ int main(int argc, char **argv)
                 EXPECT_EQUAL(s2n_connection_get_session_length(conn), 0);
 
                 EXPECT_SUCCESS(s2n_connection_free(conn));
-            }
+            };
 
             EXPECT_SUCCESS(s2n_config_free(config));
-        }
-    }
+        };
+    };
 
     /* s2n_tls13_server_nst_send */
     {
@@ -846,7 +847,7 @@ int main(int argc, char **argv)
 
             EXPECT_SUCCESS(s2n_stuffer_free(&stuffer));
             EXPECT_SUCCESS(s2n_connection_free(conn));
-        }
+        };
 
         /* Protocol is less than TLS13 */
         {
@@ -868,7 +869,7 @@ int main(int argc, char **argv)
 
             EXPECT_SUCCESS(s2n_stuffer_free(&stuffer));
             EXPECT_SUCCESS(s2n_connection_free(conn));
-        }
+        };
 
         /* 0 tickets are requested */
         {
@@ -901,7 +902,7 @@ int main(int argc, char **argv)
             EXPECT_SUCCESS(s2n_stuffer_free(&stuffer));
             EXPECT_SUCCESS(s2n_connection_free(conn));
             EXPECT_SUCCESS(s2n_config_free(config));
-        }
+        };
 
         /* Sends one new session ticket */
         {
@@ -934,13 +935,10 @@ int main(int argc, char **argv)
             EXPECT_SUCCESS(s2n_stuffer_skip_read(&stuffer, record_len));
             EXPECT_EQUAL(s2n_stuffer_data_available(&stuffer), 0);
 
-            /* Check handshake.io is cleaned up */
-            EXPECT_EQUAL(s2n_stuffer_space_remaining(&conn->handshake.io), 0);
-
             EXPECT_SUCCESS(s2n_stuffer_free(&stuffer));
             EXPECT_SUCCESS(s2n_connection_free(conn));
             EXPECT_SUCCESS(s2n_config_free(config));
-        }
+        };
 
         /* Send no more tickets if keying material is expired
          *
@@ -1006,7 +1004,7 @@ int main(int argc, char **argv)
             EXPECT_SUCCESS(s2n_stuffer_free(&stuffer));
             EXPECT_SUCCESS(s2n_connection_free(conn));
             EXPECT_SUCCESS(s2n_config_free(config));
-        }
+        };
 
         /* s2n_config_set_session_tickets_onoff used to enable tickets */
         {
@@ -1056,7 +1054,7 @@ int main(int argc, char **argv)
             EXPECT_SUCCESS(s2n_stuffer_free(&stuffer));
             EXPECT_SUCCESS(s2n_connection_free(conn));
             EXPECT_SUCCESS(s2n_config_free(config));
-        }
+        };
 
         /* s2n_config_set_initial_ticket_count used to enable tickets */
         {
@@ -1089,7 +1087,7 @@ int main(int argc, char **argv)
             EXPECT_SUCCESS(s2n_stuffer_free(&stuffer));
             EXPECT_SUCCESS(s2n_connection_free(conn));
             EXPECT_SUCCESS(s2n_config_free(config));
-        }
+        };
 
         /* Sends multiple new session tickets */
         {
@@ -1133,7 +1131,7 @@ int main(int argc, char **argv)
             EXPECT_SUCCESS(s2n_stuffer_free(&stuffer));
             EXPECT_SUCCESS(s2n_connection_free(conn));
             EXPECT_SUCCESS(s2n_config_free(config));
-        }
+        };
 
         /* Test S2N_TLS13_MAX_FIXED_NEW_SESSION_TICKET_SIZE */
         {
@@ -1170,11 +1168,11 @@ int main(int argc, char **argv)
                 uint32_t expected_max_size = s2n_stuffer_data_available(&output) - S2N_TLS_RECORD_HEADER_LENGTH;
                 uint32_t expected_max_fixed_size = expected_max_size - session_state_size;
                 if (S2N_TLS13_MAX_FIXED_NEW_SESSION_TICKET_SIZE != expected_max_fixed_size) {
-                    fprintf(stdout, "\nS2N_TLS13_MAX_FIXED_NEW_SESSION_TICKET_SIZE (%i) should be %i\n",
+                    fprintf(stdout, "\nS2N_TLS13_MAX_FIXED_NEW_SESSION_TICKET_SIZE (%i) should be %u\n",
                             (int) S2N_TLS13_MAX_FIXED_NEW_SESSION_TICKET_SIZE, expected_max_fixed_size);
                 }
                 EXPECT_EQUAL(S2N_TLS13_MAX_FIXED_NEW_SESSION_TICKET_SIZE, expected_max_fixed_size);
-            }
+            };
 
             EXPECT_SUCCESS(s2n_stuffer_wipe(&output));
             conn->tickets_to_send++;
@@ -1196,7 +1194,7 @@ int main(int argc, char **argv)
                 uint32_t expected_max_size = s2n_stuffer_data_available(&output) - S2N_TLS_RECORD_HEADER_LENGTH;
                 uint32_t expected_max_fixed_size = expected_max_size - session_state_size;
                 EXPECT_EQUAL(S2N_TLS13_MAX_FIXED_NEW_SESSION_TICKET_SIZE, expected_max_fixed_size);
-            }
+            };
 
             EXPECT_SUCCESS(s2n_stuffer_wipe(&output));
             conn->tickets_to_send++;
@@ -1221,13 +1219,13 @@ int main(int argc, char **argv)
                 uint32_t expected_max_size = s2n_stuffer_data_available(&output) - S2N_TLS_RECORD_HEADER_LENGTH;
                 uint32_t expected_max_fixed_size = expected_max_size - session_state_size;
                 EXPECT_EQUAL(S2N_TLS13_MAX_FIXED_NEW_SESSION_TICKET_SIZE, expected_max_fixed_size);
-            }
+            };
 
             EXPECT_SUCCESS(s2n_stuffer_free(&output));
             EXPECT_SUCCESS(s2n_connection_free(conn));
             EXPECT_SUCCESS(s2n_config_free(config));
-        }
-    }
+        };
+    };
 
     /* Functional test: s2n_negotiate sends new session tickets after the handshake is complete */
     if (s2n_is_tls13_fully_supported()) {
