@@ -13,37 +13,35 @@
  * permissions and limitations under the License.
  */
 
+#include "tls/s2n_signature_algorithms.h"
+
 #include "api/s2n.h"
-
-#include "s2n_test.h"
-#include "testlib/s2n_testlib.h"
-
 #include "crypto/s2n_fips.h"
 #include "crypto/s2n_rsa_pss.h"
-
+#include "s2n_test.h"
+#include "testlib/s2n_testlib.h"
 #include "tls/s2n_cipher_suites.h"
 #include "tls/s2n_config.h"
 #include "tls/s2n_connection.h"
-#include "tls/s2n_signature_scheme.h"
-#include "tls/s2n_signature_algorithms.h"
 #include "tls/s2n_security_policies.h"
+#include "tls/s2n_signature_scheme.h"
 
-#define LENGTH 3
+#define LENGTH       3
 #define STUFFER_SIZE (LENGTH * TLS_SIGNATURE_SCHEME_LEN + 10)
 
-#define RSA_CIPHER_SUITE &s2n_ecdhe_rsa_with_aes_128_cbc_sha
+#define RSA_CIPHER_SUITE   &s2n_ecdhe_rsa_with_aes_128_cbc_sha
 #define ECDSA_CIPHER_SUITE &s2n_ecdhe_ecdsa_with_aes_128_cbc_sha
 #define TLS13_CIPHER_SUITE &s2n_tls13_aes_128_gcm_sha256
 
 const struct s2n_signature_scheme *const test_signature_schemes[] = {
-        &s2n_ecdsa_secp384r1_sha384,
-        &s2n_rsa_pkcs1_sha256,
-        &s2n_rsa_pkcs1_sha224,
+    &s2n_ecdsa_secp384r1_sha384,
+    &s2n_rsa_pkcs1_sha256,
+    &s2n_rsa_pkcs1_sha224,
 };
 
 const struct s2n_signature_preferences test_preferences = {
-        .count = LENGTH,
-        .signature_schemes = test_signature_schemes,
+    .count = LENGTH,
+    .signature_schemes = test_signature_schemes,
 };
 
 int main(int argc, char **argv)
@@ -85,7 +83,7 @@ int main(int argc, char **argv)
             conn->actual_protocol_version = S2N_TLS13;
             EXPECT_EQUAL(s2n_supported_sig_schemes_count(conn), LENGTH);
             EXPECT_EQUAL(s2n_supported_sig_scheme_list_size(conn), LENGTH * TLS_SIGNATURE_SCHEME_LEN);
-        }
+        };
 
         /* Test: if some signatures are not supported, exclude them from the count */
         {
@@ -93,11 +91,11 @@ int main(int argc, char **argv)
             /* Do not include s2n_ecdsa_secp384r1_sha384, which has a minimum version of tls13 */
             EXPECT_EQUAL(s2n_supported_sig_schemes_count(conn), LENGTH - 1);
             EXPECT_EQUAL(s2n_supported_sig_scheme_list_size(conn), (LENGTH - 1) * TLS_SIGNATURE_SCHEME_LEN);
-        }
+        };
 
         s2n_connection_free(conn);
         s2n_config_free(config);
-    }
+    };
 
     /* s2n_send_supported_sig_scheme_list */
     {
@@ -141,7 +139,7 @@ int main(int argc, char **argv)
             }
 
             EXPECT_EQUAL(s2n_stuffer_data_available(&result), 0);
-        }
+        };
 
         /* Test: do not send unsupported signatures */
         {
@@ -175,10 +173,10 @@ int main(int argc, char **argv)
             EXPECT_EQUAL(s2n_stuffer_data_available(&result), 0);
 
             EXPECT_EQUAL(signatures.len, LENGTH);
-            for (int i=0; i < LENGTH; i++) {
+            for (int i = 0; i < LENGTH; i++) {
                 EXPECT_EQUAL(signatures.iana_list[i], test_signature_schemes[i]->iana_value);
             }
-        }
+        };
 
         /* Test: do not send TLS1.2 signature schemes if QUIC enabled */
         {
@@ -202,7 +200,7 @@ int main(int argc, char **argv)
         s2n_connection_free(conn);
         s2n_config_free(config);
         s2n_stuffer_free(&result);
-    }
+    };
 
     /* s2n_get_and_validate_negotiated_signature_scheme */
     {
@@ -238,7 +236,7 @@ int main(int argc, char **argv)
             EXPECT_SUCCESS(s2n_get_and_validate_negotiated_signature_scheme(conn, &choice, &result));
             EXPECT_EQUAL(result.iana_value, s2n_rsa_pkcs1_sha256.iana_value);
             EXPECT_BYTEARRAY_EQUAL(&result, &s2n_rsa_pkcs1_sha256, sizeof(struct s2n_signature_scheme));
-        }
+        };
 
         /* Test: don't negotiate invalid signatures (protocol not high enough) */
         {
@@ -254,7 +252,7 @@ int main(int argc, char **argv)
             conn->actual_protocol_version = S2N_TLS12;
             EXPECT_FAILURE_WITH_ERRNO(s2n_get_and_validate_negotiated_signature_scheme(conn, &choice, &result),
                     S2N_ERR_INVALID_SIGNATURE_SCHEME);
-        }
+        };
 
         /* Test: don't negotiate invalid signatures (protocol too high) */
         {
@@ -270,26 +268,25 @@ int main(int argc, char **argv)
             conn->actual_protocol_version = S2N_TLS13;
             EXPECT_FAILURE_WITH_ERRNO(s2n_get_and_validate_negotiated_signature_scheme(conn, &choice, &result),
                     S2N_ERR_INVALID_SIGNATURE_SCHEME);
-        }
+        };
 
         s2n_connection_free(conn);
         s2n_config_free(config);
         s2n_stuffer_free(&choice);
-    }
-
+    };
 
     /* Test: choose correct signature for duplicate iana values.
      * Some signature schemes have the same iana, but are different for
      * different protocol versions. */
     {
         const struct s2n_signature_scheme *const dup_test_signature_schemes[] = {
-                &s2n_ecdsa_secp384r1_sha384,
-                &s2n_ecdsa_sha384,
+            &s2n_ecdsa_secp384r1_sha384,
+            &s2n_ecdsa_sha384,
         };
 
         const struct s2n_signature_preferences dup_test_preferences = {
-                .count = 2,
-                .signature_schemes = dup_test_signature_schemes,
+            .count = 2,
+            .signature_schemes = dup_test_signature_schemes,
         };
 
         struct s2n_config *config = s2n_config_new();
@@ -331,7 +328,7 @@ int main(int argc, char **argv)
         s2n_connection_free(conn);
         s2n_config_free(config);
         s2n_stuffer_free(&choice);
-    }
+    };
 
     /* s2n_choose_default_sig_scheme */
     {
@@ -375,14 +372,14 @@ int main(int argc, char **argv)
                         conn->secure->cipher_suite = RSA_CIPHER_SUITE;
                         EXPECT_SUCCESS(s2n_choose_default_sig_scheme(conn, &result, S2N_SERVER));
                         EXPECT_EQUAL(result.iana_value, s2n_rsa_pkcs1_md5_sha1.iana_value);
-                    }
+                    };
 
                     /* Choose ECDSA for a ECDSA cipher suite. */
                     {
                         conn->secure->cipher_suite = ECDSA_CIPHER_SUITE;
                         EXPECT_SUCCESS(s2n_choose_default_sig_scheme(conn, &result, S2N_SERVER));
                         EXPECT_EQUAL(result.iana_value, s2n_ecdsa_sha1.iana_value);
-                    }
+                    };
 
                     /* Ignore the type of the client certificate. */
                     {
@@ -390,15 +387,15 @@ int main(int argc, char **argv)
                         conn->handshake_params.client_cert_pkey_type = S2N_PKEY_TYPE_RSA;
                         EXPECT_SUCCESS(s2n_choose_default_sig_scheme(conn, &result, S2N_SERVER));
                         EXPECT_EQUAL(result.iana_value, s2n_ecdsa_sha1.iana_value);
-                    }
+                    };
 
                     /* When in doubt, choose RSA. */
                     {
                         conn->secure->cipher_suite = TLS13_CIPHER_SUITE;
                         EXPECT_SUCCESS(s2n_choose_default_sig_scheme(conn, &result, S2N_SERVER));
                         EXPECT_EQUAL(result.iana_value, s2n_rsa_pkcs1_md5_sha1.iana_value);
-                    }
-                }
+                    };
+                };
 
                 /* For the client signature, the auth type must match the type of the client certificate */
                 {
@@ -407,14 +404,14 @@ int main(int argc, char **argv)
                         conn->handshake_params.client_cert_pkey_type = S2N_PKEY_TYPE_RSA;
                         EXPECT_SUCCESS(s2n_choose_default_sig_scheme(conn, &result, S2N_CLIENT));
                         EXPECT_EQUAL(result.iana_value, s2n_rsa_pkcs1_md5_sha1.iana_value);
-                    }
+                    };
 
                     /* Choose ECDSA for a ECDSA certificate */
                     {
                         conn->handshake_params.client_cert_pkey_type = S2N_PKEY_TYPE_ECDSA;
                         EXPECT_SUCCESS(s2n_choose_default_sig_scheme(conn, &result, S2N_CLIENT));
                         EXPECT_EQUAL(result.iana_value, s2n_ecdsa_sha1.iana_value);
-                    }
+                    };
 
                     /* Ignore the auth type of the cipher suite */
                     {
@@ -422,9 +419,9 @@ int main(int argc, char **argv)
                         conn->handshake_params.client_cert_pkey_type = S2N_PKEY_TYPE_ECDSA;
                         EXPECT_SUCCESS(s2n_choose_default_sig_scheme(conn, &result, S2N_CLIENT));
                         EXPECT_EQUAL(result.iana_value, s2n_ecdsa_sha1.iana_value);
-                    }
-                }
-            }
+                    };
+                };
+            };
 
             /*
              * For TLS1.2, always choose either RSA-SHA1 or ECDSA depending on the auth method.
@@ -439,14 +436,14 @@ int main(int argc, char **argv)
                         conn->secure->cipher_suite = RSA_CIPHER_SUITE;
                         EXPECT_SUCCESS(s2n_choose_default_sig_scheme(conn, &result, S2N_SERVER));
                         EXPECT_EQUAL(result.iana_value, s2n_rsa_pkcs1_sha1.iana_value);
-                    }
+                    };
 
                     /* Choose ECDSA for a ECDSA cipher suite. */
                     {
                         conn->secure->cipher_suite = ECDSA_CIPHER_SUITE;
                         EXPECT_SUCCESS(s2n_choose_default_sig_scheme(conn, &result, S2N_SERVER));
                         EXPECT_EQUAL(result.iana_value, s2n_ecdsa_sha1.iana_value);
-                    }
+                    };
 
                     /* Ignore the type of the client certificate. */
                     {
@@ -454,15 +451,15 @@ int main(int argc, char **argv)
                         conn->handshake_params.client_cert_pkey_type = S2N_PKEY_TYPE_RSA;
                         EXPECT_SUCCESS(s2n_choose_default_sig_scheme(conn, &result, S2N_SERVER));
                         EXPECT_EQUAL(result.iana_value, s2n_ecdsa_sha1.iana_value);
-                    }
+                    };
 
                     /* When in doubt, choose RSA. */
                     {
                         conn->secure->cipher_suite = TLS13_CIPHER_SUITE;
                         EXPECT_SUCCESS(s2n_choose_default_sig_scheme(conn, &result, S2N_SERVER));
                         EXPECT_EQUAL(result.iana_value, s2n_rsa_pkcs1_sha1.iana_value);
-                    }
-                }
+                    };
+                };
 
                 /* For the client signature, the auth type must match the type of the client certificate */
                 {
@@ -471,14 +468,14 @@ int main(int argc, char **argv)
                         conn->handshake_params.client_cert_pkey_type = S2N_PKEY_TYPE_RSA;
                         EXPECT_SUCCESS(s2n_choose_default_sig_scheme(conn, &result, S2N_CLIENT));
                         EXPECT_EQUAL(result.iana_value, s2n_rsa_pkcs1_sha1.iana_value);
-                    }
+                    };
 
                     /* Choose ECDSA for a ECDSA certificate */
                     {
                         conn->handshake_params.client_cert_pkey_type = S2N_PKEY_TYPE_ECDSA;
                         EXPECT_SUCCESS(s2n_choose_default_sig_scheme(conn, &result, S2N_CLIENT));
                         EXPECT_EQUAL(result.iana_value, s2n_ecdsa_sha1.iana_value);
-                    }
+                    };
 
                     /* Ignore the auth type of the cipher suite */
                     {
@@ -486,14 +483,14 @@ int main(int argc, char **argv)
                         conn->handshake_params.client_cert_pkey_type = S2N_PKEY_TYPE_ECDSA;
                         EXPECT_SUCCESS(s2n_choose_default_sig_scheme(conn, &result, S2N_CLIENT));
                         EXPECT_EQUAL(result.iana_value, s2n_ecdsa_sha1.iana_value);
-                    }
-                }
-            }
+                    };
+                };
+            };
 
             s2n_connection_free(conn);
             s2n_config_free(config);
         }
-    }
+    };
 
     /* s2n_choose_sig_scheme_from_peer_preference_list */
     {
@@ -532,8 +529,8 @@ int main(int argc, char **argv)
 
             /* Choose default if empty peer list */
             struct s2n_sig_scheme_list peer_list = {
-                    .len = 0,
-                    .iana_list = { 0 },
+                .len = 0,
+                .iana_list = { 0 },
             };
             EXPECT_SUCCESS(s2n_choose_sig_scheme_from_peer_preference_list(conn, &peer_list, &result));
             EXPECT_EQUAL(result.iana_value, default_scheme.iana_value);
@@ -542,7 +539,7 @@ int main(int argc, char **argv)
             conn->secure->cipher_suite = TLS13_CIPHER_SUITE;
             conn->actual_protocol_version = S2N_TLS13;
             EXPECT_SUCCESS(s2n_choose_sig_scheme_from_peer_preference_list(conn, &peer_list, &result));
-        }
+        };
 
         /* Test: no shared valid signature schemes, using TLS1.3. Server picks preferred */
         {
@@ -550,16 +547,17 @@ int main(int argc, char **argv)
             conn->actual_protocol_version = S2N_TLS13;
 
             struct s2n_sig_scheme_list peer_list = {
-                    .len = 2, .iana_list = {
-                            s2n_rsa_pkcs1_sha224.iana_value, /* Invalid (wrong protocol version) */
-                            s2n_rsa_pkcs1_sha1.iana_value, /* Not in preference list */
-                    },
+                .len = 2,
+                .iana_list = {
+                        s2n_rsa_pkcs1_sha224.iana_value, /* Invalid (wrong protocol version) */
+                        s2n_rsa_pkcs1_sha1.iana_value,   /* Not in preference list */
+                },
             };
 
             /* behavior is that we fallback to a preferred signature algorithm */
             EXPECT_SUCCESS(s2n_choose_sig_scheme_from_peer_preference_list(conn, &peer_list, &result));
             EXPECT_EQUAL(result.iana_value, s2n_ecdsa_sha384.iana_value);
-        }
+        };
 
         /* Test: no shared valid signature schemes, using TLS1.2 */
         {
@@ -568,7 +566,8 @@ int main(int argc, char **argv)
 
             /* Peer list contains no signature schemes that we support */
             struct s2n_sig_scheme_list peer_list = {
-                    .len = 1, .iana_list = { 0 },
+                .len = 1,
+                .iana_list = { 0 },
             };
 
             EXPECT_SUCCESS(s2n_choose_sig_scheme_from_peer_preference_list(conn, &peer_list, &result));
@@ -583,7 +582,7 @@ int main(int argc, char **argv)
             struct s2n_signature_scheme default_scheme;
             EXPECT_SUCCESS(s2n_choose_default_sig_scheme(conn, &default_scheme, S2N_SERVER));
             EXPECT_EQUAL(result.iana_value, default_scheme.iana_value);
-        }
+        };
 
         /* Test: choose valid signature from peer list */
         {
@@ -591,25 +590,27 @@ int main(int argc, char **argv)
             conn->actual_protocol_version = S2N_TLS12;
 
             struct s2n_sig_scheme_list peer_list = {
-                    .len = 4, .iana_list = {
-                            s2n_ecdsa_secp384r1_sha384.iana_value, /* Invalid: wrong protocol, wrong auth method */
-                            s2n_rsa_pkcs1_sha1.iana_value,  /* Invalid: not in preference list */
-                            s2n_rsa_pkcs1_sha256.iana_value, /* Valid -- should be chosen */
-                            s2n_rsa_pkcs1_sha224.iana_value, /* Valid, but lower priority -- should not be chosen */
-                    },
+                .len = 4,
+                .iana_list = {
+                        s2n_ecdsa_secp384r1_sha384.iana_value, /* Invalid: wrong protocol, wrong auth method */
+                        s2n_rsa_pkcs1_sha1.iana_value,         /* Invalid: not in preference list */
+                        s2n_rsa_pkcs1_sha256.iana_value,       /* Valid -- should be chosen */
+                        s2n_rsa_pkcs1_sha224.iana_value,       /* Valid, but lower priority -- should not be chosen */
+                },
             };
 
             EXPECT_SUCCESS(s2n_choose_sig_scheme_from_peer_preference_list(conn, &peer_list, &result));
             EXPECT_EQUAL(result.iana_value, s2n_rsa_pkcs1_sha256.iana_value);
             EXPECT_BYTEARRAY_EQUAL(&result, &s2n_rsa_pkcs1_sha256, sizeof(struct s2n_signature_scheme));
-        }
+        };
 
         /* Test: invalid scheme, because wrong protocol version */
         {
             conn->secure->cipher_suite = RSA_CIPHER_SUITE;
 
             struct s2n_sig_scheme_list peer_list = {
-                    .len = 1, .iana_list = { s2n_rsa_pkcs1_sha224.iana_value },
+                .len = 1,
+                .iana_list = { s2n_rsa_pkcs1_sha224.iana_value },
             };
 
             conn->actual_protocol_version = S2N_TLS12;
@@ -620,11 +621,11 @@ int main(int argc, char **argv)
             conn->actual_protocol_version = S2N_TLS13;
             EXPECT_FAILURE_WITH_ERRNO(s2n_choose_sig_scheme_from_peer_preference_list(conn, &peer_list, &result),
                     S2N_ERR_INVALID_SIGNATURE_SCHEME);
-        }
+        };
 
         s2n_connection_free(conn);
         s2n_config_free(config);
-    }
+    };
 
     /* Test: send and receive default signature preferences */
     {
@@ -662,18 +663,18 @@ int main(int argc, char **argv)
 
         s2n_connection_free(conn);
         s2n_stuffer_free(&result);
-    }
+    };
 
     /* Test: libcrypto may not support PSS signatures */
     {
         const struct s2n_signature_scheme *const pss_test_signature_schemes[] = {
-                &s2n_rsa_pss_rsae_sha256,
-                &s2n_rsa_pss_pss_sha256,
+            &s2n_rsa_pss_rsae_sha256,
+            &s2n_rsa_pss_pss_sha256,
         };
 
         const struct s2n_signature_preferences pss_test_preferences = {
-                .count = 2,
-                .signature_schemes = pss_test_signature_schemes,
+            .count = 2,
+            .signature_schemes = pss_test_signature_schemes,
         };
 
         struct s2n_config *config = s2n_config_new();
@@ -711,14 +712,14 @@ int main(int argc, char **argv)
             EXPECT_EQUAL(size, s2n_supported_sig_scheme_list_size(conn));
             if (s2n_is_rsa_pss_certs_supported()) {
                 EXPECT_EQUAL(size, 2 * sizeof(uint16_t));
-            }  else if (s2n_is_rsa_pss_signing_supported()) {
+            } else if (s2n_is_rsa_pss_signing_supported()) {
                 EXPECT_EQUAL(size, 1 * sizeof(uint16_t));
             } else {
                 EXPECT_EQUAL(size, 0);
             }
 
             s2n_stuffer_free(&result);
-        }
+        };
 
         /* Do not accept a PSS signature scheme if unsupported:
          * s2n_get_and_validate_negotiated_signature_scheme + PSS */
@@ -738,13 +739,14 @@ int main(int argc, char **argv)
             }
 
             s2n_stuffer_free(&choice);
-        }
+        };
 
         /* Do not choose a PSS signature scheme if unsupported:
          * s2n_choose_sig_scheme_from_peer_preference_list + PSS */
         {
             struct s2n_sig_scheme_list peer_list = {
-                    .len = 1, .iana_list = { s2n_rsa_pss_rsae_sha256.iana_value },
+                .len = 1,
+                .iana_list = { s2n_rsa_pss_rsae_sha256.iana_value },
             };
 
             struct s2n_signature_scheme result;
@@ -756,15 +758,14 @@ int main(int argc, char **argv)
                 EXPECT_FAILURE_WITH_ERRNO(s2n_choose_sig_scheme_from_peer_preference_list(conn, &peer_list, &result),
                         S2N_ERR_INVALID_SIGNATURE_SCHEME);
             }
-        }
+        };
 
         s2n_connection_free(conn);
         s2n_config_free(config);
-    }
+    };
 
     /* Test fallback of TLS 1.3 signature algorithms */
-    if (s2n_is_rsa_pss_signing_supported())
-    {
+    if (s2n_is_rsa_pss_signing_supported()) {
         struct s2n_config *config = s2n_config_new();
 
         struct s2n_connection *conn = s2n_connection_new(S2N_SERVER);
@@ -801,14 +802,15 @@ int main(int argc, char **argv)
             conn->actual_protocol_version = S2N_TLS13;
 
             struct s2n_sig_scheme_list peer_list = {
-                    .len = 1, .iana_list = {
+                .len = 1,
+                .iana_list = {
                         s2n_rsa_pkcs1_sha224.iana_value, /* Invalid (wrong protocol version) */
-                    },
+                },
             };
 
             EXPECT_FAILURE_WITH_ERRNO(s2n_choose_sig_scheme_from_peer_preference_list(conn, &peer_list, &result),
-                S2N_ERR_INVALID_SIGNATURE_SCHEME);
-        }
+                    S2N_ERR_INVALID_SIGNATURE_SCHEME);
+        };
 
         EXPECT_SUCCESS(s2n_config_add_cert_chain_and_key_to_store(config, rsa_cert_chain));
 
@@ -818,15 +820,16 @@ int main(int argc, char **argv)
             conn->actual_protocol_version = S2N_TLS13;
 
             struct s2n_sig_scheme_list peer_list = {
-                    .len = 1, .iana_list = {
+                .len = 1,
+                .iana_list = {
                         s2n_rsa_pkcs1_sha224.iana_value, /* Invalid (wrong protocol version) */
-                    },
+                },
             };
 
             /* behavior is that we fallback to a preferred signature algorithm */
             EXPECT_SUCCESS(s2n_choose_sig_scheme_from_peer_preference_list(conn, &peer_list, &result));
             EXPECT_EQUAL(result.iana_value, s2n_rsa_pss_rsae_sha256.iana_value);
-        }
+        };
 
         s2n_connection_free(conn);
         s2n_config_free(config);
