@@ -245,7 +245,7 @@ int main(int argc, char **argv)
         };
 
         /* Takes an input blob and writes to out stuffer then encrypt the payload */
-        EXPECT_SUCCESS(s2n_record_write(conn, TLS_HANDSHAKE, &in));
+        EXPECT_OK(s2n_record_write(conn, TLS_HANDSHAKE, &in));
 
         /* Verify opaque content type in tls 1.3 */
         EXPECT_EQUAL(conn->out.blob.data[0], TLS_APPLICATION_DATA);
@@ -298,7 +298,7 @@ int main(int argc, char **argv)
         struct s2n_blob plaintext = { .data = hello_data, .size = sizeof(hello_data) - 1 };
 
         /* Takes an input blob and writes to out stuffer then encrypt the payload */
-        EXPECT_SUCCESS(s2n_record_write(conn, TLS_HANDSHAKE, &plaintext));
+        EXPECT_OK(s2n_record_write(conn, TLS_HANDSHAKE, &plaintext));
 
         /* Reset sequence number */
         conn->secure->client_sequence_number[7] = 0;
@@ -369,7 +369,7 @@ int main(int argc, char **argv)
             struct s2n_blob in = { .data = change_cipher_spec, .size = sizeof(change_cipher_spec) };
 
             /* Takes an input blob and writes to out stuffer then encrypt the payload */
-            EXPECT_SUCCESS(s2n_record_write(conn, TLS_CHANGE_CIPHER_SPEC, &in));
+            EXPECT_OK(s2n_record_write(conn, TLS_CHANGE_CIPHER_SPEC, &in));
 
             S2N_STUFFER_READ_EXPECT_EQUAL(&conn->out, TLS_CHANGE_CIPHER_SPEC, uint8);
             S2N_STUFFER_READ_EXPECT_EQUAL(&conn->out, 0x0303, uint16);
@@ -379,7 +379,7 @@ int main(int argc, char **argv)
             EXPECT_SUCCESS(s2n_stuffer_wipe(&conn->out));
 
             /* An encrypted TLS 1.3 HANDSHAKE type will look like a APPLICATION_DATA over the wire */
-            EXPECT_SUCCESS(s2n_record_write(conn, TLS_HANDSHAKE, &in));
+            EXPECT_OK(s2n_record_write(conn, TLS_HANDSHAKE, &in));
 
             /* now test that application data writes encrypted payload */
             S2N_STUFFER_READ_EXPECT_EQUAL(&conn->out, TLS_APPLICATION_DATA, uint8);
