@@ -22,6 +22,4 @@
 extern const s2n_extension_type s2n_server_status_request_extension;
 
 /* Old-style extension functions -- remove after extensions refactor is complete */
-int s2n_server_extensions_status_request_send_size(struct s2n_connection *conn);
-int s2n_server_extensions_status_request_send(struct s2n_connection *conn, struct s2n_stuffer *out);
 int s2n_recv_server_status_request(struct s2n_connection *conn, struct s2n_stuffer *extension);
